<HTML>
<!--
FastPACS 
2006-2008 by Precision Diagnostic Systems, Inc.
Maple Park, IL 60151 USA

Based on the copyrighted work of Takaya Sakusabe

On-Line Support
Contents copyright Precision Diagnostic Systems, Inc.
Maple Park, IL 60151 USA

Spanish Localization 2007 by Precision Diagnostic Systems, Inc.
-->
<%@ Import Namespace="System.Xml" %>
<%@ Import Namespace="System.Globalization" %>
<%@ Import Namespace="DIOWave" %>
<%@ Import Namespace="System.IO" %>
<script src="classes.cs" runat="server" />
<script src="viewer-common.cs" runat="server" />
<script src="viewer-custom.cs" runat="server" />
<script runat="server">
//========================================================================================

	//==============================
	// QueryStringValue Class
	//==============================
	class QueryStringValue : QueryStringValueBase {
	
		public readonly String volume;
		public readonly String path;
		public readonly String image_path;
		public readonly UInt32 window_width;
		public readonly UInt32 window_height;
		public readonly String voi;
		public readonly Single scale;
		public readonly Int32 zx;
		public readonly Int32 zy;
		public readonly String action;
		public readonly String overlay;
		public readonly String clientip;

		public readonly bool bad;

		public QueryStringValue(HttpRequest req, BrowserCheck browser, StringDictionary pref)
			: base(req) {

			UInt32 width_margin = 2;
			UInt32 height_margin = 2;

			if (browser.type == "NN") {
				if (browser.os == "M") {
					width_margin = 8;
					height_margin = 8;
				} else if (browser.os == "W") {
					width_margin = 4;
					height_margin = 4;
				}
			} else if (browser.type == "IE") {
				if (browser.os == "M") {
					width_margin = 16;
					height_margin = 16;
				} else {
					width_margin = 2;
					height_margin = 8;
				}
			}

			this.volume = get_opt_str("VOLUME", null);
			this.path = get_opt_str("PATH", null);
			this.image_path = get_opt_str("IMAGE", null);
			this.window_width = (UInt32)(get_opt_int("WW", 600) - width_margin);
			this.window_height = (UInt32)(get_opt_int("WH", 400) - height_margin);

			this.voi = get_opt_str("VOI", null);
			this.scale = Single.Parse(get_opt_str("SCALE", "0"));
			this.zx = get_opt_int("ZX", -1);
			this.zy = get_opt_int("ZY", -1);

			this.action = get_val("ACTION", pref, default_action, "Z");
			this.overlay = get_val("OVERLAY", pref, default_overlay, "N");
			this.clientip = get_opt_str("CLIENTIP", "R0M0");
	
			this.bad = this.volume == null || this.path == null || this.image_path == null;
		}
	}

	//==============================
	//
	//==============================
	DicomStudy loadDOM(QueryStringValue qsv, XmlDocument config_dom) {
		String volume = qsv.volume;
		String path = qsv.path;
		String image_path = qsv.image_path;

		DicomStudy dom = null;
		StudyCache dw_obj = (StudyCache)Application.Get("StudyDOM");
		XmlNode vol = config_dom.SelectSingleNode("/DIOWaveConfiguration/VOLUME[@label=\"" + volume + "\"]");
		String dir = vol.SelectSingleNode("directory").InnerText;
		String studyLoc = vol.SelectSingleNode("location").InnerText + "/" + path;
		if (dir.StartsWith("\\")) {
			dom = dw_obj.GetRemoteDicomStudy("http://localhost/DIOWave/scripts/dio-study.dll" + studyLoc);
		} else {
			dom = dw_obj.GetDicomStudy(studyLoc);
		}

		SOPInstanceObject file = null;
		foreach (SOPInstanceObject f in dom.fl) {
			if (f.path != image_path)
				continue;
			file = f;
			break;
		}
		if (file == null)
			return null;

		ArrayList new_fl = new ArrayList();
		new_fl.Add(file);

		dom.fl = new_fl;
		dom.el = null;

		return dom;
	}

	//==============================
	//
	//==============================
	void printImageList(ArrayList image_list, ImageSpaceObject s) {

		Writer.Write("var IL = new Array(" + image_list.Count + ");\n");
		UInt32 i = 0;
		foreach (ImageObject img in image_list)
			Writer.Write("IL[" + i++ + "] = new IR(" + img.new_args(s) + ");\n");
	}

	//==============================
	//
	//==============================
	void print_study_info_ex(DicomStudy dom) {
		Writer.Write("#" + get_data_IS(null, dom, 0x00200013, String.Empty));
	}

	//==============================
	//
	//
	//
	//==============================
	class LayoutObject {
		public readonly UInt32 canvasHeight, canvasWidth;
		public readonly UInt32 imageHeight, imageWidth;
		public readonly UInt32 viewHeight, viewWidth;
		public readonly Double scale, fit_scale, zoom_scale;
		public readonly bool full;

		public LayoutObject(QueryStringValue qsv, DicomStudy dom) {

			this.canvasHeight = qsv.window_height - kInfoBarHeight - kMenuBarHeight;
			this.canvasWidth = qsv.window_width - kStripWidth;

			foreach (DataElementObject deo in ((SOPInstanceObject)dom.fl[0]).data) {
				if (deo.tag < 0x00280010) {
					continue;
				} else if (deo.tag == 0x00280010) {
					this.imageHeight = (UInt16)deo.value;
					continue;
				} else if (deo.tag == 0x00280011) {
					this.imageWidth = (UInt16)deo.value;
					break;
				} else {
					break;
				}
			}
			if (qsv.clientip[1] == '1' || qsv.clientip[1] == '3') {
				UInt32 tmp = this.imageHeight;
				this.imageHeight = this.imageWidth;
				this.imageWidth = tmp;
			}

			Double hscale = (Double)this.canvasWidth / (Double)this.imageWidth;
			Double vscale = (Double)this.canvasHeight / (Double)this.imageHeight;
			this.fit_scale = Math.Floor(Math.Min(hscale, vscale) * 100) / 100;
		
			this.scale = qsv.scale == 0 ? this.fit_scale : qsv.scale;
		
			this.viewHeight = (UInt32)Math.Ceiling((Double)this.imageHeight * this.scale);
			if (this.viewHeight > this.canvasHeight)
				this.viewHeight = this.canvasHeight;
		
			this.viewWidth = (UInt32)Math.Ceiling((Double)this.imageWidth * this.scale);
			if (this.viewWidth > this.canvasWidth)
				this.viewWidth = this.canvasWidth;
		
			for (Double scale = 2; scale > this.fit_scale * 1.5; scale /= 2)
				this.zoom_scale = scale;
		
			this.full = this.canvasHeight == this.viewHeight && this.canvasWidth == this.viewWidth;
		}
	}

	//==============================
	//
	//==============================
	void printImageTable(LayoutObject layout) {

		UInt32 hs = layout.canvasWidth - layout.viewWidth;
		UInt32 vs = layout.canvasHeight - layout.viewHeight;

		UInt32 hsl = (UInt32)Math.Floor((Double)hs / 2);
		UInt32 hsr = hs - hsl;

		UInt32 vst = (UInt32)Math.Floor((Double)vs / 2);
		UInt32 vsb = vs - vst;

		Writer.Write("<TABLE ALIGN='LEFT' HSPACE='0' VSPACE='0' CELLPADDING='0' CELLSPACING='0' BORDER='0' WIDTH='" + layout.canvasWidth + "' HEIGHT='" + layout.canvasHeight + "'>\n");

		if (vst > 0) {
			Writer.Write("<TR>\n");
			if (hsl > 0)
				Writer.Write("\t<TD HEIGHT='" + vst + "' WIDTH='" + hsl + "'></TD>\n");
			Writer.Write("\t<TD HEIGHT='" + vst + "' WIDTH='" + layout.viewWidth + "'></TD>\n");
			if (hsr > 0)
				Writer.Write("\t<TD HEIGHT='" + vst + "' WIDTH='" + hsr + "'></TD>\n");
			Writer.Write("<TR>\n");
		}
		
		Writer.Write("<TR>\n");

		if (hsl > 0)
			Writer.Write("\t<TD HEIGHT='" + layout.viewHeight + "' WIDTH='" + hsl + "'></TD>\n");

		Writer.Write("\t<TD HEIGHT='" + layout.viewHeight + "' WIDTH='" + layout.viewWidth + "'>");

		if (m_browser.type == "NN") {
			Writer.Write("<ILAYER ID='ANC-0' TOP='0' LEFT='0' WIDTH='0' HEIGHT='0' Z-INDEX='0' VISIBILITY='HIDDEN'></ILAYER>");
			Writer.Write("<LAYER ID='ANN-0' TOP='0' LEFT='0' HEIGHT='" + layout.viewHeight + "' WIDTH='" + layout.viewWidth + "' Z-INDEX='1' VISIBILITY='HIDDEN'></LAYER>");
			Writer.Write("<LAYER ID='ACT-0' TOP='0' LEFT='0' HEIGHT='" + layout.viewHeight + "' WIDTH='" + layout.viewWidth + "' Z-INDEX='2' VISIBILITY='HIDDEN'></LAYER>");
		} else if (m_browser.type == "IE" && m_browser.os == "W") {
			Writer.Write("<DIV ID='ANN-0' CLASS='ANN'></DIV>");
			Writer.Write("<DIV ID='ACT-0' CLASS='ACT'>");
			if (m_browser.version >= 5.5) {
				Writer.Write("<TABLE HSPACE='0' VSPACE='0' CELLPADDING='0' CELLSPACING='0' BORDER='0' WIDTH='100%' HEIGHT='100%'>");
	 			Writer.Write("<TR><TD ID='ACTTD-0'></TD></TR>");
				Writer.Write("</TABLE>");
			}
			Writer.Write("</DIV>");
		}

		if (m_browser.type == "IE" && m_browser.version >= 5.5)
			Writer.Write("<IMG NAME='IMG-0' BORDER='0' HSPACE='0' VSPACE='0'>");
		else
			Writer.Write("<IMG NAME='IMG-0' BORDER='0' HSPACE='0' VSPACE='0' WIDTH='" + layout.viewWidth + "' HEIGHT='" + layout.viewHeight + "' SRC='/DIOWave/bbox.gif'>");

		Writer.Write("</TD>\n");

		if (hsr > 0)
			Writer.Write("\t<TD HEIGHT='" + layout.viewHeight + "' WIDTH='" + hsr + "'></TD>\n");
		
		Writer.Write("</TR>\n");

		if (vsb > 0) {
			Writer.Write("<TR>\n");
			if (hsl > 0)
				Writer.Write("\t<TD HEIGHT='" + vsb + "' WIDTH='" + hsl + "'></TD>\n");
			Writer.Write("\t<TD HEIGHT='" + vsb + "' WIDTH='" + layout.viewWidth + "'></TD>\n");
			if (hsr > 0)
				Writer.Write("\t<TD HEIGHT='" + vsb + "' WIDTH='" + hsr + "'></TD>\n");
			Writer.Write("</TR>\n");
		}
		
		Writer.Write("</TABLE>");
	}

	//==========================
	//
	//==========================
	void print_pixel_info(SOPInstanceObject file) {
		UInt16 bitsStored = get_data_US(file, null, 0x00280101, 0);
		UInt16 pixelRep = get_data_US(file, null, 0x00280103, 0);

		Writer.Write("<NOBR>Bits Stored: <FONT COLOR='white'>" + bitsStored + " ");

		Writer.Write("[");
		if (pixelRep == 1)
			Writer.Write((-(1 << (int)(bitsStored - 1))).ToString() + " .. " + ((1 << (int)(bitsStored - 1)) - 1).ToString());
		else
			Writer.Write("0 .. " + ((1 << (int)bitsStored) - 1).ToString());
		Writer.Write("]");

		Writer.Write("</FONT></NOBR>; \n");
	}

	//==========================
	//
	//==========================
	void print_image_dimensions(SOPInstanceObject file) {

		ArrayList pixelSpacing = get_data_array(file, null, 0x00280030);
		if (pixelSpacing != null && pixelSpacing.Count == 2) {
			try {
				Double psx = Double.Parse((String)pixelSpacing[0], DS_ns);
				Double psy = Double.Parse((String)pixelSpacing[1], DS_ns);
				Writer.Write("<NOBR>Spacing: <FONT COLOR='white'>" + psx.ToString("F3") + " x " + psy.ToString("F3") + "</FONT></NOBR>; \n");
			} catch (FormatException fe) {
				// maybe it is empty DS elements
				// prevent to throw the exception to caller
			}
		}

		String sliceThickness = get_data_DS(file, null, 0x00180050, null);
		if (sliceThickness != null) {
			try {
				Double val = Double.Parse(sliceThickness, DS_ns);
				Writer.Write("<NOBR>Thickness: <FONT COLOR='white'>" + val.ToString("F2") + "</FONT></NOBR>; \n");
			} catch (FormatException fe) {
				// maybe it is empty DS elements
				// prevent to throw the exception to caller
			}
		}
	
	}

	//==============================
	//
	//==============================
	void printSeriesDetail(DicomStudy dom, QueryStringValue qsv) {

		SOPInstanceObject file = (SOPInstanceObject)dom.fl[0];

		if (m_browser.type == "NN")
			Writer.Write("<LAYER CLASS='SeriesDetail' ID='SeriesDetail' VISIBILITY='HIDDEN' Z-INDEX='4' WIDTH='" + (qsv.window_width - kStripWidth - 2) + "'><FONT COLOR='#E0E0C0'>");
		else
			Writer.Write("<DIV CLASS='SeriesDetail' ID='SeriesDetail'>");

		print_pixel_info(file);
		print_image_dimensions(file);

		print_desc_text(file, 0x00180015, "Body Part Examined", 0);
		print_desc_text(file, 0x00185101, "View Position", 0);
		print_desc_text(file, 0x00181160, "Filter Type", 0);
		print_desc_text(file, 0x00181180, "Collimator/grid Name", 0);
		print_desc_text(file, 0x00181190, "Focal Spot", 0);
		print_desc_text(file, 0x00181260, "Plate Type", 0);
		print_desc_text(file, 0x00181261, "Phosphor Type", 0);
		print_desc_text(file, 0x00180060, "KVP", 0);
		print_desc_text(file, 0x00181104, "Plate ID", 0);
		print_desc_text(file, 0x00181110, "Distance Source to Detector", 0);
		print_desc_text(file, 0x00181111, "Distance Source to Patient", 0);
		print_desc_text(file, 0x00181150, "Exposure Time", 0);
		print_desc_text(file, 0x00181151, "X-ray Tube Current", 0);
		print_desc_text(file, 0x00181152, "Exposure", 0);
		print_desc_text(file, 0x00181164, "Imager Pixel Spacing", 0);
		print_desc_text(file, 0x00181170, "Generator Power", 0);
		print_desc_text(file, 0x00181400, "Acquisition Device Processing Description", 0);
		print_desc_text(file, 0x00181401, "Acquisition Device Processing Code", 0);
		print_desc_text(file, 0x00181402, "Cassette Orientation", 0);
		print_desc_text(file, 0x00181403, "Cassette Size", 0);
		print_desc_text(file, 0x00186000, "Sensitivity", 0);
		print_desc_text(file, 0x00100030, "Patient's DOB", 0);
		print_desc_text(file, 0x00101010, "Patient's Age", 0);
		print_desc_text(file, 0x00100040, "Sex", 0);

		if (m_browser.type == "NN")
			Writer.Write("</FONT><ILAYER></ILAYER></LAYER>\n");
		else
			Writer.Write("</DIV>\n");
	}

	//==============================
	//
	//==============================
	void printSeriesDetailButton() {
		if (m_browser.type == "NN")
			Writer.Write("<A STYLE='color:white;' HREF='javascript:void();' onClick='show_series_detail(); return true;'>Detalle</A>");
		else
			Writer.Write("<A STYLE='color:white;' HREF='javascript:show_series_detail()'>Detalle</A>");
	}

	//==============================
	//
	//
	//
	//==============================
	class VOIMenu : MenuBase {
		//==============================
		//
		//==============================
		public VOIMenu(VOITableObject voiTable) {
			this.table = new ArrayList();
			foreach (VOIEntry voi in voiTable.table)
				this.table.Add(new MenuItem(voi.wc.ToString() + "," + voi.ww.ToString(), voi.label));
		}
	}

	//==============================
	//
	//
	//
	//==============================
	class OverlayMenu : MenuBase {
		//==============================
		//
		//==============================
		public OverlayMenu() {
			this.table = new ArrayList();
			this.table.Add(new MenuItem("N", "Numero"));
			this.table.Add(new MenuItem("D", "Detalle"));
			this.table.Add(new MenuItem(".", "Ninguno"));
		}
	}

	//==============================
	//
	//
	//
	//==============================
	class ScaleMenu : MenuBase {
		//==============================
		//
		//==============================
		public ScaleMenu(LayoutObject layout) {
			this.table = new ArrayList();
			for (Double scale = 2; scale > layout.fit_scale; scale /= 2)
				this.table.Add(new MenuItem(scale.ToString(), (scale * 100).ToString() + "%"));
			this.table.Add(new MenuItem("0", "Ajuste (" + (layout.fit_scale * 100).ToString() + "%)"));
			this.table.Reverse();
		}
	}

	//==============================
	//
	//
	//
	//==============================
	class ClientIPMenu : MenuBase {
		//==============================
		//
		//==============================
		public ClientIPMenu() {
			this.table = new ArrayList();
			this.table.Add(new MenuItem("R0M0", "Normal"));
			this.table.Add(new MenuItem("R1M0", "Rote A la derecha"));
			this.table.Add(new MenuItem("R3M0", "Rote A la izquierda"));
			this.table.Add(new MenuItem("R2M0", "Invertido"));
			this.table.Add(new MenuItem("R0M1", "Espejo"));
			this.table.Add(new MenuItem("R3M1", "Espejo+Rote A la derecha"));
			this.table.Add(new MenuItem("R1M1", "Espejo+Rote A la izquierda"));
			this.table.Add(new MenuItem("R2M1", "Espejo+Invertido"));
		}
	}

	//==============================
	//
	//
	//
	//==============================
	class ActionMenu : MenuBase {
		//==============================
		//
		//==============================
		public ActionMenu() {
			this.table = new ArrayList();
			this.table.Add(new MenuItem("Z", "Magnifique/Movimiento"));
			this.table.Add(new MenuItem("V", "W/L"));
			this.table.Add(new MenuItem(".", "Ningunos"));
		}
	}

//========================================================================================
</script>
<%
//========================================================================================

	setup(Request);
	Writer = Response.Output;

	QueryStringValue QSV = new QueryStringValue(Request, m_browser, (StringDictionary)Session["viewerpref"]);
	if (QSV.bad) {
		Response.Clear();
		Server.Transfer("/DIOWave/blank1.htm");
	}
	XmlDocument config_dom = (XmlDocument)Application.Get("DIOWaveConf");
	DicomStudy DOM = loadDOM(QSV, config_dom);

	ImageSpaceObject ImageSpace = new ImageSpaceObject();
	ArrayList ImageList = new ArrayList();
	foreach (SOPInstanceObject file in DOM.fl)
		ImageList.Add(new ImageObject(file, ImageSpace));

	LayoutObject Layout = new LayoutObject(QSV, DOM);
	VOITableObject VOITable = new VOITableObject(ImageSpace, DOM, QSV, VOIPresets(DOM));

	DrMenu ActionMenu = new DrMenu(Writer, m_browser, "Accion", "A", 96, new ActionMenu(), "change_action");
	DrMenu VOIMenu = new DrMenu(Writer, m_browser, "Alcance", "V", 108, new VOIMenu(VOITable), "preset_voi");
	DrMenu ScaleMenu = new DrMenu(Writer, m_browser, "Escala", "S", 72, new ScaleMenu(Layout), "scale_changed");
	DrMenu OverlayMenu = new DrMenu(Writer, m_browser, "Recubrimiento", "O", 64, new OverlayMenu(), "change_overlay");
	DrMenu ClientIPMenu = new DrMenu(Writer, m_browser, "Vision", "I", 96, new ClientIPMenu(), "client_ip");

//========================================================================================
%>
<HEAD>
<TITLE>Series Viewer</TITLE>
<META HTTP-EQUIV="Content-Type" CONTENT="text/html; charset="utf-8">
</HEAD>
<SCRIPT LANGUAGE="JavaScript1.2">
//----------------------------------------------------------------------------------------
// Viewer independed code
//----------------------------------------------------------------------------------------
//------------------------------
//
//------------------------------
function prettyTime(time) {
	var str = new String(time);
	return str.substr(0, 2) + ':' + str.substr(2, 2) + ':' + str.substr(4, 4);
}

//------------------------------
//
//------------------------------
function round_ceil(v, f) {
	return (Math.ceil(v * f) / f).toString();
}

//------------------------------
// Image Object
//------------------------------
function IR(file, imageNumber, imageDate, imageTime, rows, cols, xs, ys, x, y, z, xd, yd, wc, ww) {
	this.file = file;
	this.number = imageNumber;
	this.date = imageDate;
	this.time = imageTime;
	this.rows = rows;
	this.cols = cols;
	this.xs = xs;
	this.ys = ys;
	this.x = x;
	this.y = y;
	this.z = z;
	this.xd = xd;
	this.yd = yd;
	this.wc = wc;
	this.ww = ww;
}

//------------------------------
//
//------------------------------
IR.prototype.uri = function() {
	return '/DIOWave/scripts/dio-image.dll'
	     + '<%=config_dom.SelectSingleNode("/DIOWaveConfiguration/VOLUME[@label=\"" + QSV.volume + "\"]/location").InnerText%>'
	     + '/'
	     + '<%=QSV.path%>'
	     + '/'
	     + this.file;
}

//------------------------------
// ImageBox
//------------------------------
function ImageBox(img, index) {
	this.img = img;
	this.index = index;
	this.loaded = true;
}
//------------------------------
//
//------------------------------
ImageBox.prototype.reload = function() {
	this.img.src = IDS.image_src(this.index, false);
}

//------------------------------
//
//------------------------------
ImageBox.prototype.start_track_update = function() {
	this.img.onload = onImageLoad;
	this.loaded = true;
}

//------------------------------
//
//------------------------------
ImageBox.prototype.track_update = function(nocache) {
	if (this.loaded) {
		this.loaded = false;
		this.img.src = IDS.image_src(this.index, nocache);
	}
}

//------------------------------
//
//------------------------------
ImageBox.prototype.end_track_update = function() {
	this.img.onload = null;
}

//------------------------------
//
//------------------------------
ImageBox.prototype.set_annotation = function() {
	set_annotation1(IDS.overlay, this.index);
}

//------------------------------
//
//------------------------------
function onActionMouseDown(e, action) {
<% if (m_browser.type == "IE") { %>
	e = window.event;
	if (e.button != 1 || e.shiftKey || e.altKey || e.ctlKey)
		return true;
<% } else if (m_browser.type == "NN") { %>
	if (e.which != 1 || (e.modifiers & (Event.ALT_MASK | Event.CONTROL_MASK | Event.SHIFT_MASK)) != 0)
		return true;
<% } else { %>
	if (e.altKey || e.ctrlKey || e.shiftKey || e.metaKey)
		return true;
<% } %>

	CurrentAction = action;
	CurrentAction.mousedown(e);
	CurrentAction.begin_drag(e);

<% if (m_browser.type == "IE") { %>
 	document.onmousemove = onDocumentMouseMove;
 	document.onmouseup = onDocumentMouseUp;
	e.cancelBubble = true;
<% } else if (m_browser.type == "NN") { %>
 	document.onMouseMove = onDocumentMouseMove;
 	document.onMouseUp = onDocumentMouseUp;
 	document.captureEvents(Event.MOUSEMOVE | Event.MOUSEUP);
<% } else { %>
 	document.onmousemove = onDocumentMouseMove;
 	document.onmouseup = onDocumentMouseUp;
<% } %>
	return false;
}

//------------------------------
//
//------------------------------
function onDocumentMouseUp(e) {
<% if (m_browser.type == "IE") { %>
	e = window.event;
<% } %>

	if (CurrentAction != null) {
		CurrentAction.end_drag(e);
		CurrentAction = null;
	}

<% if (m_browser.type == "IE") { %>
 	document.onmousemove = null;
 	document.onmouseup = null;
	e.cancelBubble = true;
<% } else if (m_browser.type == "NN") { %>
  	document.releaseEvents(Event.MOUSEMOVE | Event.MOUSEUP);
 	document.onMouseMove = null;
 	document.onMouseUp = null;
<% } else { %>
 	document.onmousemove = null;
 	document.onmouseup = null;
<% } %>
	return false;
}

//------------------------------
//
//------------------------------
function onDocumentMouseMove(e) {
<% if (m_browser.type == "IE") { %>
	e = window.event;
<% } %>

	if (CurrentAction != null)
		CurrentAction.do_drag(e);

<% if (m_browser.type == "IE") { %>
	e.cancelBubble = true;
<% } %>
	return false;
}

//------------------------------
// ImageActionObject
//------------------------------
function ImageActionObject() {
	this.md_imageX = -1;
	this.md_imageY = -1;
	this.md_pageX = -1;
	this.md_pageY = -1;

	this.mode = '.';

	this.anchor_x = -1;
	this.anchor_y = -1;
	this.anchor_X = -1;
	this.anchor_Y = -1;

	this.org_wc = -1;
	this.org_ww = -1;

	this.org_first_index = -1;

	this.box = null;
}

//------------------------------
//
//------------------------------
function ActionObject_mousedown(e) {
<% if (m_browser.type == "IE") { %>
 	this.md_imageX = e.offsetX;
	this.md_imageY = e.offsetY;
	this.md_pageX = e.clientX;
	this.md_pageY = e.clientY;
<% } else { %>
	this.md_imageX = e.layerX;
	this.md_imageY = e.layerY;
	this.md_pageX = e.pageX;
	this.md_pageY = e.pageY;
<% } %>
}
//------------------------------
ImageActionObject.prototype.mousedown = ActionObject_mousedown;

//------------------------------
//
//------------------------------
function ActionObject_x(e) {
<% if (m_browser.type == "IE") { %>
	return this.md_imageX + e.clientX - this.md_pageX;
<% } else { %>
	return this.md_imageX + e.pageX - this.md_pageX;
<% } %>
}
//------------------------------
ImageActionObject.prototype.x = ActionObject_x;

//------------------------------
//
//------------------------------
function ActionObject_y(e) {
<% if (m_browser.type == "IE") { %>
	return this.md_imageY + e.clientY - this.md_pageY;
<% } else { %>
	return this.md_imageY + e.pageY - this.md_pageY;
<% } %>
}
//------------------------------
ImageActionObject.prototype.y = ActionObject_y;

//------------------------------
//
//------------------------------
function ActionObject_offset_x(e) {
<% if (m_browser.type == "IE") { %>
	return e.clientX - this.md_pageX;
<% } else { %>
	return e.pageX - this.md_pageX;
<% } %>
}
//------------------------------
ImageActionObject.prototype.offset_x = ActionObject_offset_x;

//------------------------------
//
//------------------------------
function ActionObject_offset_y(e) {
<% if (m_browser.type == "IE") { %>
	return e.clientY - this.md_pageY;
<% } else { %>
	return e.pageY - this.md_pageY;
<% } %>
}
//------------------------------
ImageActionObject.prototype.offset_y = ActionObject_offset_y;

//------------------------------
//
//------------------------------
function onImageMouseDown(e) {
	return onActionMouseDown(e, ImageAction);
}

//------------------------------
//
//------------------------------
function SetVarText(id, val) {
<% if (m_browser.type == "NN") { %>
	var laydoc = document.layers[id].document.layers[0].document;
	laydoc.open('text/html', 'replace');
	laydoc.write(val);
	laydoc.close();
<% } else { %>
	var div = document.<%=m_cfn.getElementById%>(id);
	div.<%=m_cfn.innerText%> = val;
<% } %>
}

//------------------------------
//
//------------------------------
function setVOIText() {
	var wc = IDS.wc;
	var ww = IDS.ww;
	if (wc == 0 && ww == 0) {
		wc = "";
		ww = "";
	}
	SetVarText('WC', wc);
	SetVarText('WW', ww);
}

//------------------------------
//
//------------------------------
function change_action(arg) {
	if (IDS.action == arg)
		return;
	IDS.action = arg;
	setActionText();
	setup_action(arg);
	ping("ACTION=" +  arg);
}

//------------------------------
//
//------------------------------
function change_overlay(arg) {
	if (IDS.overlay == arg)
		return;
	IDS.overlay = arg;
	setup_annotations(arg);
	ping("OVERLAY=" +  arg);
}

//------------------------------
//
//------------------------------
function drmenu_item_click(sig, handler, value) {
<% if (m_browser.type == "NN") { %>
	var menu_list = document.layers['DrMenuList-' + sig];
	menu_list.visibility = 'hidden';
<% } else { %>
	var menu_list = document.<%=m_cfn.getElementById%>('DrMenuList-' + sig);
	menu_list.style.display = 'none';
<% } %>
	if (handler != null)
		handler(value);
}

//------------------------------
//
//------------------------------
function drmenu_init(sig) {
<% if (m_browser.type == "NN") { %>
	var anchor = document.layers['DrMenuAnchor-' + sig];
	var menu_button = document.layers['DrMenuButton-' + sig];
	var menu_list = document.layers['DrMenuList-' + sig];
	menu_button.moveTo(anchor.pageX, anchor.pageY);
	menu_button.resizeTo(anchor.clip.width, anchor.clip.height);
	menu_list.moveTo(anchor.pageX, anchor.pageY + <%=(kMenuBarHeight - 6)%>);
	menu_button.onMouseOver = new Function("event", "drmenu_event(event, true, '" + sig + "', true); return false;");
	menu_button.onMouseOut = new Function("event", "drmenu_event(event, false, '" + sig + "', true); return false;");
	menu_list.onMouseOver = new Function("event", "drmenu_event(event, true, '" + sig + "', false); return false;");
	menu_list.onMouseOut = new Function("event", "drmenu_event(event, false, '" + sig + "', false); return false;"); 
<% } else { %>
	var left = 0;
	var top = 0;
	var menu_button = document.<%=m_cfn.getElementById%>('DrMenuButton-' + sig);
	var div = menu_button;
	while (div.tagName != "BODY") {
		left += div.offsetLeft;
		top += div.offsetTop;
		div = div.offsetParent;
	}
	var menu_list = document.<%=m_cfn.getElementById%>('DrMenuList-' + sig);
	menu_list.style.<%=m_cfn.posLeft%> = left + 1;
	menu_list.style.<%=m_cfn.posTop%> = top + <%=kMenuBarHeight%>;
	menu_list.style.display = 'none';
<% } %>
}

//------------------------------
//
//------------------------------
function drmenu_event(event, onOver, sig, onButton) {
<% if (m_browser.type == "NN") { %>
	var menu_list = document.layers['DrMenuList-' + sig];
	if (onOver)
		menu_list.visibility = 'show';
	else
		menu_list.visibility = 'hidden';
<% } else if (m_browser.type == "IE") { %>
	event.cancelBubble = true;
	event.returnValue = false;
	var menu_list = document.all('DrMenuList-' + sig);
	if (onOver) {
		if (menu_list.style.display != 'block')
			menu_list.style.display = 'block';
	} else {
		if (menu_list.style.display != 'none') {
			menu_list.style.display = 'none';
		}
	}
<% } else { %>
<%  if (m_browser.type == "GE" && m_browser.version < 1.1) { %>
	onOver = event.clientX >= event.currentTarget.offsetLeft && event.clientX <= event.currentTarget.offsetLeft + event.currentTarget.offsetWidth
	      && event.clientY >= event.currentTarget.offsetTop && event.clientY <= event.currentTarget.offsetTop + event.currentTarget.offsetHeight;
<%  } %>
	var menu_list = document.getElementById('DrMenuList-' + sig);
	if (onOver) {
		if (menu_list.style.display != 'block')
			menu_list.style.display = 'block';
	} else {
		if (menu_list.style.display != 'none') {
			menu_list.style.display = 'none';
		}
	}
<% } %>
}

//------------------------------
//
//------------------------------
function SetupSeriesDetail() {
<% if (m_browser.type == "NN") { %>
	var lay = document.layers['SeriesDetail'];
	var alay = lay.document.layers[0];
	lay.moveTo(0, <%=QSV.window_height%> - alay.pageY - 16);
<% } else { %>
	var div = document.<%=m_cfn.getElementById%>('SeriesDetail');
	div.style.<%=m_cfn.posLeft%> = 1;
	div.style.<%=m_cfn.posTop%> = <%=QSV.window_height%> - div.offsetHeight;
	div.style.display = 'none';
<% } %>
}

//------------------------------
//
//------------------------------
function show_series_detail() {
<% if (m_browser.type == "NN") { %>
	var lay = document.layers['SeriesDetail'];
	if (lay.visibility != 'show')
		lay.visibility = 'show';
	else
		lay.visibility = 'hidden';
<% } else { %>
	var div = document.<%=m_cfn.getElementById%>('SeriesDetail');
	if (div.style.display == 'none')
		div.style.display = 'block';
	else
		div.style.display = 'none';
<% } %>
}

//----------------------------------------------------------------------------------------
</SCRIPT>
<SCRIPT LANGUAGE="JavaScript1.2">
//----------------------------------------------------------------------------------------
// Viewer dependant code
//----------------------------------------------------------------------------------------

<% if (m_browser.type == "NN") { %>
//------------------------------
//
//------------------------------
IR.prototype.get_annotation = function(flag) {
	if (flag == 'N') {
		return '<SPAN CLASS="ANNTEXT">' + this.number + '</SPAN>';
	} else if (flag == 'D') {

		var fovx = Math.floor(this.cols * this.xs * (<%=QSV.clientip[1] == '1' || QSV.clientip[1] == '3' ? Layout.viewHeight : Layout.viewWidth%> / (this.cols * IDS.scale)) + 0.5);
		var fovy = Math.floor(this.rows * this.ys * (<%=QSV.clientip[1] == '1' || QSV.clientip[1] == '3' ? Layout.viewWidth : Layout.viewHeight%> / (this.rows * IDS.scale)) + 0.5);

		var TL = 'No: ' + this.number;
		var fovx = Math.floor(this.cols * this.xs * (<%=QSV.clientip[1] == '1' || QSV.clientip[1] == '3' ? Layout.viewHeight : Layout.viewWidth%> / (this.cols * IDS.scale)) + 0.5);
		var fovy = Math.floor(this.rows * this.ys * (<%=QSV.clientip[1] == '1' || QSV.clientip[1] == '3' ? Layout.viewWidth : Layout.viewHeight%> / (this.rows * IDS.scale)) + 0.5);
		if (fovx != 0 && fovy != 0)
			TL += '<BR>FOV: ' + <%=QSV.clientip[1] == '1' || QSV.clientip[1] == '3' ? "fovy + 'x' + fovx" : "fovx + 'x' + fovy"%>;

		var TR = "";
		if (this.time != 0)
			TR = 'Tm: ' + prettyTime(this.time);

		var TC = '';
		var ML = '';
		var MR = '';
		var BC = '';

		return '<TABLE HSPACE="0" VSPACE="0" CELLPADDING="0" CELLSPACING="0" BORDER="0" ROWS="3" COLS="3" WIDTH="100%" HEIGHT="100%">'
		     + '<TR VALIGN="TOP" HEIGHT="40%">'
		     + '<TD ALIGN="LEFT" WIDTH="40%" CLASS="ANNTEXT">' + TL + '</TD>'
		     + '<TD ALIGN="CENTER" WIDTH="20%" CLASS="ANNTEXT">' + TC + '</TD>'
		     + '<TD ALIGN="RIGHT" WIDTH="40%" CLASS="ANNTEXT">' + TR + '</TD>'
		     + '</TR>'
		     + '<TR VALIGN="MIDDLE" HEIGHT="20%">'
		     + '<TD ALIGN="LEFT" CLASS="ANNTEXT">' + ML + '</TD>'
		     + '<TD></TD>'
		     + '<TD ALIGN="RIGHT" CLASS="ANNTEXT">' + MR + '</TD>'
		     + '</TR>'
		     + '<TR VALIGN="BOTTOM" HEIGHT="40%">'
		     + '<TD></TD>'
		     + '<TD ALIGN="CENTER" WIDTH="20%" CLASS="ANNTEXT">' + BC + '</TD>'
		     + '<TD></TD>'
		     + '</TR>'
		     + '</TABLE>';
	} else {
		return '';
	}
}
<% } else { %>
<%  if (m_browser.os == "M" && m_browser.type == "IE") { %>
//------------------------------
//
//------------------------------
IR.prototype.make_measure_table = function(key) {

	//------------------------------
	//
	//------------------------------
	function select_measure_length(pixel_spacing, limit) {
		var real_len_list = new Array(1.0, 10.0, 100.0);
		var disp_len_list = new Array(0.0,  0.0,   0.0);
		for (var i = 0; i < real_len_list.length; i++) {
			var rlen = real_len_list[i];
			var dlen = rlen / pixel_spacing;
			if (dlen < 16)
				continue;
			if (dlen > limit)
				continue;			
			disp_len_list[i] = dlen;
		}
		for (var i = disp_len_list.length - 1; i >= 0; i--) {
			var dlen = disp_len_list[i];
			if (dlen != 0.0)
				return dlen;
		}
		return 0;
	}

	var scale = IDS.scale;
	var ps, limit;
	switch (key) {
	case 'BC':
		ps = <%=QSV.clientip[1] == '1' || QSV.clientip[1] == '3' ? "this.ys" : "this.xs"%> / scale;
		limit = <%=Layout.viewWidth * 2 / 3%>;
		break;
	case 'MR':
		ps = <%=QSV.clientip[1] == '1' || QSV.clientip[1] == '3' ? "this.xs" : "this.ys"%> / scale;
		limit = <%=Layout.viewHeight * 2 / 3%>;
		break;
	}

	var length = select_measure_length(ps, limit);
	if (length == 0)
		return "";

	length = Math.floor(length + 0.5);

	var html;
	switch (key) {
	case 'BC':
		html = '<table style="position:absolute;height:6;top:<%=Layout.viewHeight - 14%>;left:' + Math.floor((<%=Layout.viewWidth%> - length) / 2) + ';width:' + length + ';border-collapse:collapse;border-bottom:1px solid #FFAA00;" cellpadding="0" cellspacing="0" cols="1" rows="1">';
		break;

	case 'MR':
		html = '<table style="position:absolute;height:' + length + ';top:' + Math.floor((<%=Layout.viewHeight%> - length) / 2) + ';left:<%=Layout.viewWidth - 14%>;border-collapse:collapse;border-right:1px solid #FFAA00;" cellpadding="0" cellspacing="0" rows="1" cols="1">';
		break;
	}

	return html + '<tr><td></td></tr></table>';

}
<%  } else { %>
//------------------------------
//
//------------------------------
IR.prototype.make_measure_table = function(key) {

	//------------------------------
	//
	//------------------------------
	function select_measure_unit(pixel_spacing, limit) {
		var real_len_list = new Array(1.0, 10.0, 100.0);
		var disp_len_list = new Array(0.0,  0.0,   0.0);
		for (var i = 0; i < real_len_list.length; i++) {
			var rlen = real_len_list[i];
			var dlen = rlen / pixel_spacing;
			if (dlen < 16)
				continue;
			if (dlen > limit)
				continue;			
			disp_len_list[i] = dlen;
		}
		for (var i = 0; i < disp_len_list.length; i++) {
			var dlen = disp_len_list[i];
			if (dlen != 0.0)
				return dlen;
		}
		return 0;
	}

	var scale = IDS.scale;
	var ps, limit;
	switch (key) {
	case 'BC':
		ps = <%=QSV.clientip[1] == '1' || QSV.clientip[1] == '3' ? "this.ys" : "this.xs"%> / scale;
		limit = <%=Layout.viewWidth * 2 / 3%>;
		break;
	case 'MR':
		ps = <%=QSV.clientip[1] == '1' || QSV.clientip[1] == '3' ? "this.xs" : "this.ys"%> / scale;
		limit = <%=Layout.viewHeight * 2 / 3%>;
		break;
	}

	var unit = select_measure_unit(ps, limit);
	if (unit == 0)
		return "";

	var count = Math.floor(limit / unit);
	if (count > 10)
		count = 10;

	var size = Math.ceil(unit * count);

	var html;
	switch (key) {
	case 'BC':
		html = '<table style="position:absolute;height:6;top:<%=Layout.viewHeight - 14%>;left:' + Math.floor((<%=Layout.viewWidth%> - size) / 2) + ';width:' + size + ';border-collapse:collapse;border-bottom:1px solid #FFAA00;" cellpadding="0" cellspacing="0" cols="' + count + '" rows="1">';
		html += '<tr style="height:5;">';
		var last_x = 0;
		for (var i = 0; i < count; i++) {
			var x = Math.floor((i + 1) * unit + 0.5);
			var width = x - last_x - 1;
			last_x = x;
			html += '<td style="width:' + width + ';';
			if (i == 0)
				html += 'border-left:1px solid #FFAA00;'
			html += 'border-right:1px solid #FFAA00;"></td>';
		}
		html += '</tr>';
		break;

	case 'MR':
		html = '<table style="position:absolute;height:' + size + ';top:' + Math.floor((<%=Layout.viewHeight%> - size) / 2) + ';left:<%=Layout.viewWidth - 14%>;border-collapse:collapse;border-right:1px solid #FFAA00;" cellpadding="0" cellspacing="0" rows="' + count + '" cols="1">';
		var last_y = 0;
		for (var i = 0; i < count; i++) {
			var y = Math.floor((i + 1) * unit + 0.5);
			var height = y - last_y;
			last_y = y;
			if (i == count - 1)
				height++;
			html += '<tr style="height:' + height + ';">';
			html += '<td style="width:5;border-top:1px solid #FFAA00;';
			if (i == count - 1)
				html += 'border-bottom:1px solid #FFAA00;';
			html += '"></td>';
			html += '</tr>';
		}
		break;
	}

	return html + '</table>';

}
<%  } %>
//------------------------------
//
//------------------------------
IR.prototype.put_annotation = function(flag, index) {
	var html = "";
	if (flag == 'N') {
		var TL = '<DIV STYLE="position:absolute;top:0;left:0;" CLASS="ANNTEXT">';
		TL += this.number;
		TL += '<DIV>';
		html = TL;
	} else if (flag == 'D') {

		var TL = '<DIV STYLE="position:absolute;top:0;left:0;" CLASS="ANNTEXT">';
		TL += 'No: ' + this.number;
		var fovx = Math.floor(this.cols * this.xs * (<%=QSV.clientip[1] == '1' || QSV.clientip[1] == '3' ? Layout.viewHeight : Layout.viewWidth%> / (this.cols * IDS.scale)) + 0.5);
		var fovy = Math.floor(this.rows * this.ys * (<%=QSV.clientip[1] == '1' || QSV.clientip[1] == '3' ? Layout.viewWidth : Layout.viewHeight%> / (this.rows * IDS.scale)) + 0.5);
		if (fovx != 0 && fovy != 0)
			TL += '<BR>FOV: ' + <%=QSV.clientip[1] == '1' || QSV.clientip[1] == '3' ? "fovy + 'x' + fovx" : "fovx + 'x' + fovy"%>;
		TL += '</DIV>';

		var TR = "";
		if (this.time != 0) {
			TR = '<table style="position:absolute;top:0;left:<%=Math.Floor(Convert.ToDouble(Layout.viewWidth / 2 + 8))%>;width:<%=Math.Floor(Convert.ToDouble(Layout.viewWidth / 2 - 8))%>;"><tr><td valign="top" align="right" CLASS="ANNTEXT">';
			TR += 'Tm: ' + prettyTime(this.time);
			TR +=  '</td></tr></table>';
		}

		var MR = this.make_measure_table('MR');

		var BC = this.make_measure_table('BC');

		html = TL +  TR + MR + BC;
	}
	var div = document.<%=m_cfn.getElementById%>('ANN-' + index);
	div.innerHTML = html;
}
<% } %>

//------------------------------
// ImageDisplaySetting
//------------------------------
function ImageDisplaySetting() {

	// Scale
	this.scale = <%=Layout.scale%>;
	this.fit = <%=(QSV.scale == 0 ? "true" : "false")%>;

	// Zoom
	this.zx = <%=(QSV.zx < 0 ? Math.Ceiling(Convert.ToDouble(Layout.imageWidth / 2)) : QSV.zx)%>;
	this.zy = <%=(QSV.zy < 0 ? Math.Ceiling(Convert.ToDouble(Layout.imageHeight / 2)) : QSV.zy)%>;

	// VOI
	this.wc = <%=VOITable.wc%>;
	this.ww = <%=VOITable.ww%>;

	// mode
	this.overlay = '<%=QSV.overlay%>';
	this.action = '<%=QSV.action%>';

	// Client side IP
	this.clientip = '<%=QSV.clientip%>';
}

//------------------------------
//
//------------------------------
ImageDisplaySetting.prototype.query_string = function() {
	return '&VOI=' + escape('' + this.wc + ',' + this.ww)
	     + (this.fit ? '' : '&SCALE=' + this.scale + '&ZX=' + this.zx + '&ZY=' + this.zy)
	     + '&ACTION=' + escape(this.action)
	     + '&OVERLAY=' + escape(IDS.overlay)
	     + (this.clientip == "R0M0" ? "" : '&CLIENTIP=' + this.clientip);
}

//------------------------------
//
//------------------------------
ImageDisplaySetting.prototype.image_src = function(index, nocache) {
	return IL[0].uri()
		+ '?WC=' + this.wc
		+ '&WW=' + this.ww
	    + '&HEIGHT=<%=(QSV.clientip[1] == '1' || QSV.clientip[1] == '3' ? Layout.viewWidth : Layout.viewHeight)%>'
	    + '&WIDTH=<%=(QSV.clientip[1] == '1' || QSV.clientip[1] == '3' ? Layout.viewHeight : Layout.viewWidth)%>'
	    + (this.fit ? '' : '&SCALE=' + this.scale
<% if (QSV.clientip == "R1M0") { %>	    
	      + '&ZX=' + this.zy + '&ZY=' + (<%=Layout.imageWidth%> - this.zx)
<% } else if (QSV.clientip == "R2M0") { %>
	      + '&ZX=' + (<%=Layout.imageWidth%> - this.zx) + '&ZY=' + (<%=Layout.imageHeight%> - this.zy)
<% } else if (QSV.clientip == "R3M0") { %>
	      + '&ZX=' + (<%=Layout.imageHeight%> - this.zy) + '&ZY=' + this.zx
<% } else if (QSV.clientip == "R0M1") { %>
	      + '&ZX=' + (<%=Layout.imageWidth%> - this.zx) + '&ZY=' + this.zy
<% } else if (QSV.clientip == "R1M1") { %>
	      + '&ZX=' + this.zy + '&ZY=' + this.zx
<% } else if (QSV.clientip == "R2M1") { %>
	      + '&ZX=' + this.zx + '&ZY=' + (<%=Layout.imageHeight%> - this.zy)
<% } else if (QSV.clientip == "R3M1") { %>
	      + '&ZX=' + (<%=Layout.imageWidth%> - this.zy) + '&ZY=' + (<%=Layout.imageHeight%> - this.zy)
<% } else { %>
	      + '&ZX=' + this.zx + '&ZY=' + this.zy
<% } %>
	      )
		+ (nocache ? '&CACHE=2' : '');
	 
}

//------------------------------
//
//------------------------------
ImageDisplaySetting.prototype.set_zoom_center = function(x, y, anchor_x, anchor_y, anchor_X, anchor_Y) {
<%/*
	X2: ړ̃}EX̉ɂȂ|Cg̃IWi摜ł̍W
	x2: ړ̃}EX̉ɂȂ|Cg̕\̍W
	C2: ړ̕\̒SɂȂ|Cg̃IWi摜̂ł̍W
	c2: ړ̕\̒SW

	X1: ړÕ}EX̉ɂ|Cg̃IWi摜̍W
	x1: ړÕ}EX̉ɂ|Cg̕\̍W
	C1: ړO̕\̒S̃|Cg̃IWi摜ł̍W
	c1: ړO̕\̒SW

	S: XP[

	X2 = X1 = X
	c2 = c1 = c

	(X2 - C2) * S = x2 - c2
	(X2 - C1) * S = x1 - c2

	(X - C2) * S = x2 - c
	(X - C1) * S = x1 - c

	C2 = (x1 - x2)/S + C1

*/%>
	var S = this.scale;

	this.zx = Math.floor((anchor_x - x)/S + anchor_X);
	this.zy = Math.floor((anchor_y - y)/S + anchor_Y);

	this.adjust_zoom_center();
}

//------------------------------
//
//------------------------------
ImageDisplaySetting.prototype.set_zoom_center2 = function(x, y, newScale) {
<%/*
	X2: Y[̃}EX̉ɂȂ|Cg̃IWi摜ł̍W
	x2: Y[̃}EX̉ɂȂ|Cg̕\̍W
	C2: Y[̕\̒SɂȂ|Cg̃IWi摜̂ł̍W
	c2: Y[̕\̒SW
	S2: Y[̃XP[

	X1: Y[Õ}EX̉ɂ|Cg̃IWi摜̍W
	x1: Y[Õ}EX̉ɂ|Cg̕\̍W
	C1: Y[O̕\̒S̃|Cg̃IWi摜ł̍W
	c1: Y[O̕\̒SW
	S1: Y[ÕXP[


	(X1 - C1) * S1 = (x1 - c1)
	(X2 - C2) * S2 = (x2 - c2)

	c1 = c2 = c
	x1 = x2 = x
	X1 = X2 = X

	(X - C1) * S1 = x - c
	(X - C2) * S2 = x - c

	X = (x - c) / S1 + C1
	  = (x - c) / S2 + C2

	C2 = C1 + (x - c)/S1 - (x - c)/S2
*/%>
	var cx = <%=Layout.viewWidth%> / 2;
	var cy = <%=Layout.viewHeight%> / 2;
	var Cx = <%=Layout.imageWidth%> / 2;
	var Cy = <%=Layout.imageHeight%> / 2;
	var S1 = this.scale;
	var S2 = newScale;

	this.zx = Math.floor(Cx + (x - cx)/S1 - (x - cx)/S2);
	this.zy = Math.floor(Cy + (y - cy)/S1 - (y - cy)/S2);

	this.scale = newScale;

	this.adjust_zoom_center();
}

//------------------------------
//
//------------------------------
ImageDisplaySetting.prototype.adjust_zoom_center = function() {
	var scale = this.scale;

	var halfX = Math.floor(<%=Layout.viewWidth%> / scale / 2);
	var halfY = Math.floor(<%=Layout.viewHeight%> / scale / 2);

	if (this.zx < halfX)
		this.zx = halfX;
	else if (this.zx > <%=Layout.imageWidth%> - halfX)
		this.zx = <%=Layout.imageWidth%> - halfX;

	if (this.zy < halfY)
		this.zy = halfY;
	else if (this.zy > <%=Layout.imageHeight%> - halfY)
		this.zy = <%=Layout.imageHeight%> - halfY;
}

//------------------------------
//
//------------------------------
ImageDisplaySetting.prototype.set_drag_voi = function(orgWC, orgWW, x, y) {
<%/*
	sсF
	ƃ}EX𓮂ŒlςĂ܂͎̂gɂB
	܂AWC ςĂ̂ WW ܂ŕςĂ܂i邢͂̋tjgɂB
	ƂƂŁAsт݂B

	܂ASsсB͂Ƃɂ̈ړȂ΂ȂɂȂB
	ɁAIsсBXDȂAY̕sт傫Ƃi邢͂̋tj
	Isт̌`͐^Bpx͂ROx

	WC ̌vZF
	}EXړʂ 256 ̎ WW ̔ςA񎟊֐
	Y = a * x^2  --- (ww / 2) = a * (256 * 256) --- a = ww / (256 * 256 * 2)

	WW ̌vZF
	}EẌړʂ E256 ̎ WW {ɁiRgXg邭jȂ
	Y = 2^X

*/%>
	var ax = Math.abs(x);
	if (ax <= 4)
		ax = 0;
	else
		ax -= 4;
	x = x < 0 ? -ax : ax;

	var ay = Math.abs(y);
	if (ay <= 4)
		ay = 0;
	else
		ay -= 4;
	y = y < 0 ? ay : -ay;

	if (ax == 0 && ay == 0)
		return;

	var tan30 = 0.57735;
	if (ax != 0 && ay / ax < tan30) {
		this.ww = Math.floor(orgWW * Math.pow(2, x / 256));
	} else if (ay != 0 && ax / ay < tan30) {
		this.wc = orgWC + Math.floor(ay * y * orgWW / 0x20000);
	} else {
		this.ww = Math.floor(orgWW * Math.pow(2, x / 256));
		this.wc = orgWC + Math.floor(ay * y * orgWW / 0x20000);
	}
}

//------------------------------
//
//------------------------------
ImageActionObject.prototype.begin_drag = function(e) {

<% if (m_browser.type == "IE") { %>
	this.box = e.srcElement.box;
<% } else if (m_browser.type == "NN") { %>
	this.box = e.target.box;
<% } else { %>
	this.box = e.currentTarget.box;
<% } %>

	this.box.start_track_update();

	if (this.mode == 'Z') {
		var x = this.x(e);
		var y = this.y(e);
		if (IDS.fit) {
			IDS.set_zoom_center2(x, y, <%=Layout.zoom_scale%>);
			IDS.fit = false;
			this.box.track_update(true);
			setScaleText();
			reload_annotation_text();
		}
		this.anchor_x = x;
		this.anchor_y = y;
		this.anchor_X = IDS.zx;
		this.anchor_Y = IDS.zy;
	} else if (this.mode == 'V') {
		this.org_wc = IDS.wc;
		this.org_ww = IDS.ww;
	}
}

//------------------------------
//
//------------------------------
ImageActionObject.prototype.do_drag = function(e) {
	if (this.mode == 'Z') {
		var x = IDS.zx;
		var y = IDS.zy;
		IDS.set_zoom_center(this.x(e), this.y(e), this.anchor_x, this.anchor_y, this.anchor_X, this.anchor_Y);
		if (IDS.zx != x || IDS.zy != y)
			this.box.track_update(true);
	} else if (this.mode == 'V') {
		var wc = IDS.wc;
		var ww = IDS.ww;
		IDS.set_drag_voi(this.org_wc, this.org_ww, this.offset_x(e), this.offset_y(e));
		if (IDS.wc != wc || IDS.ww != ww) {
			this.box.track_update(true);
			setVOIText();
		}
	}
}

//------------------------------
//
//------------------------------
ImageActionObject.prototype.end_drag = function(e) {
	if (this.mode == 'Z') {
		IDS.set_zoom_center(this.x(e), this.y(e), this.anchor_x, this.anchor_y, this.anchor_X, this.anchor_Y);
<% if (Layout.full) { %>
		reload_imgbox(ImageBoxTable);
<% } else { %>
		Reload();
<% } %>
	} else if (this.mode == 'V') {
		IDS.set_drag_voi(this.org_wc, this.org_ww, this.offset_x(e), this.offset_y(e));
		reload_imgbox(ImageBoxTable);
		setVOIText();
	}

	this.box.end_track_update();
}

//------------------------------
//
//------------------------------
function reload_imgbox(table) {
	var box = table[0];
	box.reload();
}

//------------------------------
//
//------------------------------
function set_imagefilter(img, clientip) {
	var r = clientip.charAt(1);
	var m = clientip.charAt(3);
	img.style.filter = "progid:DXImageTransform.Microsoft.BasicImage(Rotation = " + r + ", Mirror = " + m + ")";
}

//------------------------------
//
//------------------------------
function setup_imgboxes() {
	for (var i = 0; i < document.images.length; i++) {
		var img = document.images[i];
		var name = img.name;
		if (name.indexOf('IMG-') == 0) {
			var index = name.substring(4);
			var box = new ImageBox(img, parseInt(index));
			ImageBoxTable[index] = box;
			img.box = box;

<% if (m_browser.type == "IE" && m_browser.version >= 5.5) { %>
			set_imagefilter(img, IDS.clientip);
<% } %>
<% if (m_browser.type == "IE") { %>
<%  if (m_browser.version >= 5.5) { %>
			document.all('ACTTD-' + index).box = box;
<%  } else { %>
			document.all('ACT-' + index).box = box;
<%  } %>
<% } else if (m_browser.type == "NN") { %>
			var layer = document.layers['ANC-' + index];
			document.layers['ANN-' + index].moveTo(layer.pageX, layer.pageY);
			document.layers['ACT-' + index].moveTo(layer.pageX, layer.pageY);
			document.layers['ACT-' + index].document.box = box;
<% } else { %>
			document.getElementById('ACT-' + index).box = box;
<% } %>
		}
	}
}

//------------------------------
//
//------------------------------
function set_annotation1(flag, index) {
<% if (m_browser.type == "NN") { %>
	var layer = document.layers['ANN-' + index];
	if (flag == '.') {
		layer.visibility = 'hide';
	} else {
		var img = IL[0];
		var laydoc = layer.document;
		laydoc.open('text/html', 'replace');
		laydoc.write(img.get_annotation(flag));
		laydoc.close();
		layer.visibility = 'show';
	}
<% } else { %>
	var div = document.<%=m_cfn.getElementById%>('ANN-' + index);
	if (flag == '.') {
		div.style.visibility = 'hidden';
	} else {
		var img = IL[0];
		img.put_annotation(flag, 0);
		div.style.visibility = 'visible';
	}
<% } %>
}

//------------------------------
//
//------------------------------
function setup_annotations(flag) {
	set_annotation1(flag, 0);
}

//------------------------------
//
//------------------------------
function reload_annotation_text() {
	setup_annotations(IDS.overlay);
}

//------------------------------
//
//------------------------------
function setup_action(flag) {
<% if (m_browser.type == "NN") { %>
	var layer = document.layers['ACT-0'];
	if (flag == '.') {
		layer.visibility = 'hide';
		layer.document.onMouseDown = null;
		layer.document.releaseEvents(Event.MOUSEDOWN);
	} else {
		layer.visibility = 'show';
		layer.document.onMouseDown = onImageMouseDown;
		layer.document.captureEvents(Event.MOUSEDOWN);
	}
<% } else { %>
	var div = document.<%=m_cfn.getElementById%>('ACT-0');
	if (flag == '.') {
		div.style.visibility = 'hidden';
		div.onmousedown = null;
	} else {
		div.style.visibility = 'visible';
		div.onmousedown = onImageMouseDown;
	}
<% } %>
	ImageAction.mode = flag;
}

//------------------------------
//
//------------------------------
function Reload() {
	location.replace('xp-study-viewer.aspx'
	               + '?VOLUME=<%=QSV.volume%>'
	               + '&PATH=<%=QSV.path%>'
	               + '&IMAGE=<%=QSV.image_path%>'
	               + '&WW=' + <%=window_width()%>
	               + '&WH=' + <%=window_height()%>
	               + IDS.query_string());
}

//------------------------------
//
//------------------------------
function setActionText() {
	var str;
	switch (IDS.action) {
	case 'Z':
		if (IDS.fit)
			str = 'Zoom';
		else
			str = 'Pan';
		break;
	case 'V':
		str = 'W/L';
		break;
	case 'P':
		str = 'Page';
		break;
	default:
		str = '';
		break;
	}
	SetVarText('ACTION', str);
}
//------------------------------
//
//------------------------------
function setScaleText() {
	SetVarText('SCALE', Math.floor(IDS.scale * 100) + '%');
	setActionText();
}

//------------------------------
//
//------------------------------
function onImageLoad(e) {
	var box = null;
<% if (m_browser.type == "IE") { %>
	e = window.event;
	box = e.srcElement.box;
<% } else if (m_browser.type == "NN") { %>
	box = e.target.box;
<% } else { %>
	box = e.currentTarget.box;
<% } %>
	if (box != null)
		box.loaded = true;
}

//------------------------------
//
//------------------------------
function onFirstLoad() {

	setup_imgboxes();

	setVOIText();
	setScaleText();
<% if (m_browser.type == "IE" && m_browser.version >= 5.5) { %>
	SetClientIPText();
<% } %>

	reload_imgbox(ImageBoxTable);
	reload_annotation_text();

	setup_action(IDS.action);

	drmenu_init('O');
	drmenu_init('V');
	drmenu_init('S');
	drmenu_init('A');
<% if (m_browser.type == "IE" && m_browser.version >= 5.5) { %>
	drmenu_init('I');
<% } %>

	SetupSeriesDetail();

<% if (m_browser.type == "NN") { %>
	pingImage = document.layers['ping'].document.images['ping'];
<% } else { %>
	pingImage = document.images['ping'];
<% } %>

	window.onload = new Function("return false;");

	return false;
}

//------------------------------
//
//------------------------------
function scale_changed(arg) {
	arg = parseFloat(arg);
	if (arg == 0) {
		if (IDS.fit)
			return;
		IDS.fit = true;
		IDS.scale = <%=Layout.fit_scale%>;
	} else {
		if (IDS.scale == arg)
			return;
		IDS.fit = false;
		IDS.scale = arg;
	}

	Reload();
}

//------------------------------
//
//------------------------------
function client_ip(arg) {
	if (IDS.clientip == arg)
		return;
	var old = IDS.clientip;
	IDS.clientip = arg;

	if (IDS.fit) {
		var o = old.charAt(1) == '1' || old.charAt(1) == '3' ? 1 : 0;
		var a = arg.charAt(1) == '1' || arg.charAt(1) == '3' ? 1 : 0;
		if (o + a == 1) {
			Reload();
		} else {
			var img = ImageBoxTable[0].img;
			set_imagefilter(img, arg);
			reload_annotation_text();
			SetClientIPText(arg);
			ping("_CLIENTIP=" + arg);
		}
	} else {
		IDS.fit = true;
		IDS.scale = <%=Layout.fit_scale%>;
		Reload();
	}

}

//------------------------------
//
//------------------------------
function SetClientIPText() {

	if (IDS.clientip == "R1M0")
		SetVarText("ClientIP", "TurnRight");
	else if (IDS.clientip == "R3M0")
		SetVarText("ClientIP", "TurnLeft");
	else if (IDS.clientip == "R2M0")
		SetVarText("ClientIP", "UpsideDown");
	else if (IDS.clientip == "R0M1")
		SetVarText("ClientIP", "Mirror");
	else if (IDS.clientip == "R1M1")
		SetVarText("ClientIP", "Mirror+TurnLeft");
	else if (IDS.clientip == "R3M1")
		SetVarText("ClientIP", "Mirror+TurnRight");
	else if (IDS.clientip == "R2M1")
		SetVarText("ClientIP", "Mirror+UpsideDown")
	else
		SetVarText("ClientIP", "Normal");
}
//------------------------------
//
//------------------------------
function preset_voi(arg) {
	var cw = arg.split(',');

	var wc = parseInt(cw[0]);
	var ww = parseInt(cw[1]);

	if (wc == -1 && ww == -1) {
		var str = prompt('Level / Width ̌`œ͂ĂBLevel ςꍇ Level ̒lBWidth ςꍇ / Width ̌`ł', IDS.wc + ' / ' + IDS.ww);
		if (str == null || str.length == 0)
			return;
		var ary = str.match(/\s*(-?\d+)\s*\/\s*(\d+)\s*/);
		if (ary != null) {
			wc = parseInt(ary[1]);
			ww = parseInt(ary[2]);
		} else {
			ary = str.match(/\s*\/\s*(\d+)\s*/);
			if (ary != null) {
				wc = IDS.wc;
				ww = parseInt(ary[1]);
			} else {
				ary = str.match(/\s*(-?\d+)\s*/);
				if (ary != null) {
					wc = parseInt(ary[1]);
					ww = IDS.ww;
				} else {
					alert('͂ꂽl`ł܂');
					return;
				}
			}
		}
	}

	if (IDS.wc == wc && IDS.ww == ww)
		return;

	IDS.wc = wc;
	IDS.ww = ww;

	setVOIText(wc, ww);

	reload_imgbox(ImageBoxTable);
}

//------------------------------
//
//------------------------------
function ping(arg) {
	pingImage.src = "ping.aspx?" + arg;
}

//------------------------------
//
//------------------------------
<%printImageList(ImageList, ImageSpace);%>
var IDS = new ImageDisplaySetting();
var ImageBoxTable = new Array;
var ImageAction = new ImageActionObject();
var CurrentAction = null;
var pingImage = null;

//----------------------------------------------------------------------------------------
</SCRIPT>
<STYLE TYPE="text/css">
/****************************************************************************************/

BODY {
	background-color:black;
	color:white;
	font-size:10pt;

	border-width: 0 0 0 0;
<% if (m_browser.type == "NN" && m_browser.os == "M") { %>
	margin-left:-6;
	margin-top:-6;
	margin-right:0;
	margin-bottom:0;
<% } else { %>
	margin: 0 0 0 0;
<% } %>
	padding: 0 0 0 0;
}

SPAN.label {
	color:#E0E0C0;
}

NOBR.STUDY_INFO {
	font-family: monospace;
	font-size: 9pt;
}

SPAN.DIRTEXT {
	font-size:9pt;
}

TD.BAR {
	background-color:#405050; /* #687686 */
	margin:0 0 0 0;
	padding:0 0 0 0;
}

TD.STRIP {
	background-color: black;
	margin:0 0 0 0;
	padding:0 0 0 0;
}

TD.CANVAS {
	background-color: #102020;
	margin:0 0 0 0;
	padding:0 0 0 0;
}

DIV.ANN {
	position:absolute;
	height:<%=Layout.viewHeight%>;
	width:<%=Layout.viewWidth%>;
	margin:0 0 0 0;
	padding:0 0 0 0;
	visibility: hidden;
	z-index:1;
}
DIV.ACT {
	position:absolute;
	height:<%=Layout.viewHeight%>;
	width:<%=Layout.viewWidth%>;
	margin:0 0 0 0;
	padding:0 0 0 0;
	visibility: hidden;
	z-index:2;
}

.ANNTEXT {
	font-size:9pt;
	color:#FFAA00;
}

NOBR.BarText {
	font-size: <%=(m_browser.os == "M" && m_browser.type == "NN" ? 12 : 10)%>pt;
}

TD.MenuButton {
	color: white;
	font-weight: bold;
	font-family:Lucida;
	font-size: <%=(m_browser.os == "M" && m_browser.type == "NN" ? 12 : 10)%>pt;
	background-color: #687686;
	padding: 0 7 0 7;
	margin: 0 0 0 0;
}

TD.VarText {
	font-family:Lucida;
	font-size: <%=(m_browser.os == "M" && m_browser.type == "NN" ? 12 : 10)%>pt;
	background-color: #304040;
	padding: 0 0 0 2;
	margin: 0 0 0 0;
}

A.DrMenu-item {
	color: white;
	font-weight: bold;
	text-decoration: none;
}

A:hover {
	color:#FFAA00;
}

LAYER.DrMenu-list {
	color: white;
	background-color: #687686;
	border-width: 1 2 2 1;
	border-style: solid;
	border-color: #FFAA00;
	padding: 4 8 2 8;
	margin: 0 0 0 0;
}
DIV.DrMenu-list {
	position: absolute;
	z-index: 4;
 	display:none;
	color: white;
	background-color: #687686;
	border-width: 1 2 2 1;
	border-style: solid;
	border-color: #FFAA00;
	padding: 4 8 2 8;
	margin: 0 0 0 0;
}
NOBR.DrMenu-listItem {
	font-family:Lucida;
	font-size: <%=(m_browser.os == "M" && m_browser.type == "NN" ? 12 : 10)%>pt;
}


LAYER.SeriesDetail {
	background-color:#405050;
	border-width: 1;
	border-style: solid;
	border-color: #FFAA00;
	padding: 4 8 2 8;
	margin: 0 0 0 0;
	font-family:Lucida;
	font-size: <%=(m_browser.os == "M" && m_browser.type == "NN" ? 12 : 10)%>pt;
}

DIV.SeriesDetail {
	position: absolute;
	top: 0;
	left: 0;
	z-index:4;
	width: <%=(QSV.window_width - kStripWidth - 2)%>;
/* 	display:none; */
	background-color:#405050;
	border-width: 1;
	border-style: solid;
	border-color: #FFAA00;
	padding: 4 8 2 8;
	margin: 0 0 0 0;
	font-family:Lucida;
	font-size: <%=(m_browser.os == "M" && m_browser.type == "NN" ? 12 : 10)%>pt;
	color:#E0E0C0;
}

/****************************************************************************************/
</STYLE>
<BODY BGCOLOR="black" TEXT="white" onLoad="onFirstLoad()">
<DIV STYLE="width:<%=QSV.window_width%>;height:<%=kMenuBarHeight + kInfoBarHeight%>;">
	<TABLE HEIGHT="<%=kMenuBarHeight%>" ALIGN="CENTER" HSPACE="0" VSPACE="0" CELLPADDING="0" CELLSPACING="0" BORDER="0">
		<TR STYLE="height:<%=kMenuBarHeight%>;">
			<TD STYLE="padding:0 2 0 0;" ALIGN="CENTER" VALIGN="MIDDLE" NOWRAP></TD>
			<%OverlayMenu.print_menu_button();%>
			<TD STYLE="padding:0 1 0 1;" ALIGN="CENTER" VALIGN="MIDDLE" NOWRAP></TD>
			<%ActionMenu.print_menu_button();%>
			<%printVarText("ACTION", "", 32, 36, 5, 7);%>
			<TD STYLE="padding:0 1 0 1;" ALIGN="CENTER" VALIGN="MIDDLE" NOWRAP></TD>
			<%VOIMenu.print_menu_button();%>
			<%printVarText("WC", " L:", 48, 58, 5, 7);%>
			<%printVarText("WW", " W:", 42, 58, 5, 7);%>
			<TD STYLE="padding:0 1 0 1;" ALIGN="CENTER" VALIGN="MIDDLE" NOWRAP></TD>
			<%ScaleMenu.print_menu_button();%>
			<%printVarText("SCALE", "", 60, 72, 8, 14);%>
<% if (m_browser.type == "IE" && m_browser.version >= 5.5) { %>
			<TD STYLE="padding:0 1 0 1;" ALIGN="CENTER" VALIGN="MIDDLE" NOWRAP></TD>
			<%ClientIPMenu.print_menu_button();%>
			<%printVarText("ClientIP", "", 60, 72, 8, 14);%>
<% } %>
			<TD STYLE="padding:0 0 0 2;" ALIGN="CENTER" VALIGN="MIDDLE" NOWRAP></TD>
		</TR>
	</TABLE>
	<TABLE HEIGHT="<%=kInfoBarHeight%>" WIDTH="<%=QSV.window_width%>" ALIGN="CENTER" HSPACE="0" VSPACE="0" CELLPADDING="0" CELLSPACING="0" BORDER="0">
		<TR STYLE="height:<%=kInfoBarHeight%>;">
			<TD NOWRAP ALIGN="CENTER" VALIGN="MIDDLE" CLASS="BAR"><NOBR CLASS="STUDY_INFO"><%print_study_info(DOM);%><%=" "%><%print_study_info_ex(DOM);%><%=" "%><%printSeriesDetailButton();%></NOBR></TD>
		</TR>
	</TABLE>
</DIV>
<TABLE ALIGN="LEFT" HSPACE="0" VSPACE="0" CELLPADDING="0" CELLSPACING="0" BORDER="0" BGCOLOR="BLACK" WIDTH="<%=QSV.window_width%>" HEIGHT="<%=QSV.window_height - kInfoBarHeight - kMenuBarHeight%>">
<TR STYLE="height:<%=QSV.window_height - kInfoBarHeight - kMenuBarHeight%>">
<!-- CANVAS area begin -->
<TD STYLE="width:<%=QSV.window_width - kStripWidth%>;" NOWRAP ALIGN="LEFT" VALIGN="TOP" CLASS="CANVAS"><%printImageTable(Layout);%></TD>
<!-- CANVAS area end -->
<!-- STRIP area begin -->
<TD STYLE="width:<%=kStripWidth%>;" NOWRAP ALIGN="LEFT" VALIGN="TOP" CLASS="STRIP"><TABLE HEIGHT="<%=QSV.window_height - kInfoBarHeight - kMenuBarHeight%>" WIDTH="<%=kStripWidth%>" ALIGN="TOP" HSPACE="0" VSPACE="0" CELLPADDING="0" CELLSPACING="0" BORDER="0">
<TR>
	<TD><IMG SRC="/DIOWave/grayscale.gif" HEIGHT="<%=QSV.window_height - kInfoBarHeight - kMenuBarHeight%>" WIDTH="<%=kStripWidth%>" BORDER="0" HSPACE="0" VSPACE="0"></TD>
</TR>
</TABLE></TD>
<!-- STRIP area end -->
</TR>
<%
	//===================
	// Workaround for NN
	//  Ȃ LAYER łĂAsĂ܂oOւ̑Ή
	//===================
	if (m_browser.type == "NN") {
		Writer.Write("<TR><TD>\n");
		OverlayMenu.print_menu_list();
		VOIMenu.print_menu_list();
		ScaleMenu.print_menu_list();
		ActionMenu.print_menu_list();
		printSeriesDetail(DOM, QSV);
		Writer.Write("</TD></TR>\n");
	}
%>
</TABLE>
<%
	//===================
	// Workaround for IE
	//  position: absolute; ō DIV Ԃ߂Ă܂ACAEgƂłȂoOւ̑Ή
	//===================
	if (m_browser.type == "IE"
	 || m_browser.type == "GE"
	 || m_browser.type == "OP") {
		OverlayMenu.print_menu_list();
		VOIMenu.print_menu_list();
		ScaleMenu.print_menu_list();
		ActionMenu.print_menu_list();
		if (m_browser.type == "IE" && m_browser.version >= 5.5)
			ClientIPMenu.print_menu_list();
		printSeriesDetail(DOM, QSV);
	}
	
	//===================
	// Workaround for Mac IE and Gecko
	//  position: absolute; ō DIV Ԃ߂Ă܂ACAEgƂłȂoOւ̑Ή
	//===================
	if ((m_browser.type == "IE" && m_browser.os != "W")
	 || m_browser.type == "GE"
	 || m_browser.type == "OP") {
		UInt32 left = (UInt32)Math.Floor(Convert.ToDouble((Layout.canvasWidth - Layout.viewWidth) / 2));
		UInt32 top = kInfoBarHeight + kMenuBarHeight + (UInt32)Math.Floor(Convert.ToDouble((Layout.canvasHeight - Layout.viewHeight) / 2));	
		Writer.Write("<DIV ID='ANN-0' CLASS='ANN' STYLE='top:" + top + ";left:" + left + ";'></DIV>\n");
		Writer.Write("<DIV ID='ACT-0' CLASS='ACT' STYLE='top:" + top + ";left:" + left + ";'></DIV>\n");
	}
%>
<% if (m_browser.type == "NN") { %>
<LAYER ID="ping" TOP="0" LEFT="0"><A HREF="javascript:Reload()"><IMG NAME="ping" SRC="/DIOWave/minilogo.gif" BORDER="0" HSPACE="0" VSPACE="0"></A></LAYER>
<% } else { %>
<DIV STYLE="position:absolute;top:0;left:0;"><A HREF="javascript:Reload()"><IMG NAME="ping" SRC="/DIOWave/minilogo.gif" BORDER="0" HSPACE="0" VSPACE="0"></A></DIV>
<% } %>
</BODY>
</HTML>
